**BSTBLUE**

a pip package 



https://blueboy.dev     
Discord:    Blueboy0999
            [Discord](https://discordapp.com/users/1085999186681548861)
            
    


**usage:**
    bstblue.bstblue."...."
    available atributes:

    **wbdev**
    **wbdevtz**
    **wbyt**


  **website       website name**
    |                |
    wb dev----------⤴
    wbdev   : opens [https://blueboy.dev](https://blueboy.dev)



 website    website name       /text = (timezone)
    |      ↱-----⤴               |
    wb dev⤴ tz------------------⤴
    wbdevtz : opens [https://blueboy.dev/timezones](https://blueboy.dev/timezones)



 website      youtube
    |            |
    wb yt-------⤴
    wbyt    : opens [https://youtube.com](https://youtube.com)
